@@ -18,12 +18,12 @@
 struct rtnl_handle rth = { .fd = -1 };
 int preferred_family = AF_UNSPEC;
 int resolve_hosts;
-int oneline = 0;
+int oneline;
 int show_stats;
 int show_details;
 int compress_vlans;
 int timestamp;
-char * _SL_ = NULL;
+const char *_SL_;
 
 static void usage(void) __attribute__((noreturn));
 
@@ -31,10 +31,10 @@ static void usage(void)
 {
 	fprintf(stderr,
 "Usage: bridge [ OPTIONS ] OBJECT { COMMAND | help }\n"
-"where  OBJECT := { link | fdb | mdb | vlan | monitor }\n"
-"       OPTIONS := { -V[ersion] | -s[tatistics] | -d[etails] |\n"
-"                    -o[neline] | -t[imestamp] | -n[etns] name |\n"
-"                    -c[ompressvlans] }\n");
+"where	OBJECT := { link | fdb | mdb | vlan | monitor }\n"
+"	OPTIONS := { -V[ersion] | -s[tatistics] | -d[etails] |\n"
+"		     -o[neline] | -t[imestamp] | -n[etns] name |\n"
+"		     -c[ompressvlans] }\n");
 	exit(-1);
 }
 
@@ -48,9 +48,9 @@ static const struct cmd {
 	const char *cmd;
 	int (*func)(int argc, char **argv);
 } cmds[] = {
-	{ "link", 	do_link },
-	{ "fdb", 	do_fdb },
-	{ "mdb", 	do_mdb },
+	{ "link",	do_link },
+	{ "fdb",	do_fdb },
+	{ "mdb",	do_mdb },
 	{ "vlan",	do_vlan },
 	{ "monitor",	do_monitor },
 	{ "help",	do_help },
@@ -66,7 +66,8 @@ static int do_cmd(const char *argv0, int argc, char **argv)
 			return c->func(argc-1, argv+1);
 	}
 
-	fprintf(stderr, "Object \"%s\" is unknown, try \"bridge help\".\n", argv0);
+	fprintf(stderr,
+		"Object \"%s\" is unknown, try \"bridge help\".\n", argv0);
 	return -1;
 }
 
@@ -74,8 +75,9 @@ int
 main(int argc, char **argv)
 {
 	while (argc > 1) {
-		char *opt = argv[1];
-		if (strcmp(opt,"--") == 0) {
+		const char *opt = argv[1];
+
+		if (strcmp(opt, "--") == 0) {
 			argc--; argv++;
 			break;
 		}
@@ -98,7 +100,7 @@ main(int argc, char **argv)
 			++oneline;
 		} else if (matches(opt, "-timestamp") == 0) {
 			++timestamp;
-                } else if (matches(opt, "-family") == 0) {
+		} else if (matches(opt, "-family") == 0) {
 			argc--;
 			argv++;
 			if (argc <= 1)
@@ -122,13 +124,15 @@ main(int argc, char **argv)
 		} else if (matches(opt, "-compressvlans") == 0) {
 			++compress_vlans;
 		} else {
-			fprintf(stderr, "Option \"%s\" is unknown, try \"bridge help\".\n", opt);
+			fprintf(stderr,
+				"Option \"%s\" is unknown, try \"bridge help\".\n",
+				opt);
 			exit(-1);
 		}
 		argc--;	argv++;
 	}
 
-	_SL_ = oneline ? "\\" : "\n" ;
+	_SL_ = oneline ? "\\" : "\n";
 
 	if (rtnl_open(&rth, 0) < 0)
 		exit(1);
