@@ -26,18 +26,19 @@
 #include "color.h"
 
 int preferred_family = AF_UNSPEC;
-int human_readable = 0;
-int use_iec = 0;
-int show_stats = 0;
-int show_details = 0;
-int resolve_hosts = 0;
-int oneline = 0;
-int timestamp = 0;
-char * _SL_ = NULL;
-int force = 0;
+int human_readable;
+int use_iec;
+int show_stats;
+int show_details;
+int resolve_hosts;
+int oneline;
+int brief;
+int timestamp;
+const char *_SL_;
+int force;
 int max_flush_loops = 10;
-int batch_mode = 0;
-bool do_all = false;
+int batch_mode;
+bool do_all;
 
 struct rtnl_handle rth = { .fd = -1 };
 
@@ -48,14 +49,14 @@ static void usage(void)
 	fprintf(stderr,
 "Usage: ip [ OPTIONS ] OBJECT { COMMAND | help }\n"
 "       ip [ -force ] -batch filename\n"
-"where  OBJECT := { link | addr | addrlabel | route | rule | neigh | ntable |\n"
-"                   tunnel | tuntap | maddr | mroute | mrule | monitor | xfrm |\n"
+"where  OBJECT := { link | address | addrlabel | route | rule | neighbor | ntable |\n"
+"                   tunnel | tuntap | maddress | mroute | mrule | monitor | xfrm |\n"
 "                   netns | l2tp | fou | tcp_metrics | token | netconf }\n"
 "       OPTIONS := { -V[ersion] | -s[tatistics] | -d[etails] | -r[esolve] |\n"
 "                    -h[uman-readable] | -iec |\n"
 "                    -f[amily] { inet | inet6 | ipx | dnet | mpls | bridge | link } |\n"
 "                    -4 | -6 | -I | -D | -B | -0 |\n"
-"                    -l[oops] { maximum-addr-flush-attempts } |\n"
+"                    -l[oops] { maximum-addr-flush-attempts } | -br[ief] |\n"
 "                    -o[neline] | -t[imestamp] | -ts[hort] | -b[atch] [filename] |\n"
 "                    -rc[vbuf] [size] | -n[etns] name | -a[ll] | -c[olor]}\n");
 	exit(-1);
@@ -64,7 +65,7 @@ static void usage(void)
 static int do_help(int argc, char **argv)
 {
 	usage();
-        return 0;
+	return 0;
 }
 
 static const struct cmd {
@@ -89,7 +90,7 @@ static const struct cmd {
 	{ "tap",	do_iptuntap },
 	{ "token",	do_iptoken },
 	{ "tcpmetrics",	do_tcp_metrics },
-	{ "tcp_metrics",do_tcp_metrics },
+	{ "tcp_metrics", do_tcp_metrics },
 	{ "monitor",	do_ipmonitor },
 	{ "xfrm",	do_xfrm },
 	{ "mroute",	do_multiroute },
@@ -105,9 +106,8 @@ static int do_cmd(const char *argv0, int argc, char **argv)
 	const struct cmd *c;
 
 	for (c = cmds; c->cmd; ++c) {
-		if (matches(argv0, c->cmd) == 0) {
+		if (matches(argv0, c->cmd) == 0)
 			return -(c->func(argc-1, argv+1));
-		}
 	}
 
 	fprintf(stderr, "Object \"%s\" is unknown, try \"ip help\".\n", argv0);
@@ -119,12 +119,14 @@ static int batch(const char *name)
 	char *line = NULL;
 	size_t len = 0;
 	int ret = EXIT_SUCCESS;
+	int orig_family = preferred_family;
 
 	batch_mode = 1;
 
 	if (name && strcmp(name, "-") != 0) {
 		if (freopen(name, "r", stdin) == NULL) {
-			fprintf(stderr, "Cannot open file \"%s\" for reading: %s\n",
+			fprintf(stderr,
+				"Cannot open file \"%s\" for reading: %s\n",
 				name, strerror(errno));
 			return EXIT_FAILURE;
 		}
@@ -140,12 +142,15 @@ static int batch(const char *name)
 		char *largv[100];
 		int largc;
 
+		preferred_family = orig_family;
+
 		largc = makeargs(line, largv, 100);
 		if (largc == 0)
 			continue;	/* blank line */
 
 		if (do_cmd(largv[0], largc, largv)) {
-			fprintf(stderr, "Command failed %s:%d\n", name, cmdlineno);
+			fprintf(stderr, "Command failed %s:%d\n",
+				name, cmdlineno);
 			ret = EXIT_FAILURE;
 			if (!force)
 				break;
@@ -172,7 +177,8 @@ int main(int argc, char **argv)
 
 	while (argc > 1) {
 		char *opt = argv[1];
-		if (strcmp(opt,"--") == 0) {
+
+		if (strcmp(opt, "--") == 0) {
 			argc--; argv++;
 			break;
 		}
@@ -185,8 +191,8 @@ int main(int argc, char **argv)
 			argv++;
 			if (argc <= 1)
 				usage();
-                        max_flush_loops = atoi(argv[1]);
-                } else if (matches(opt, "-family") == 0) {
+			max_flush_loops = atoi(argv[1]);
+		} else if (matches(opt, "-family") == 0) {
 			argc--;
 			argv++;
 			if (argc <= 1)
@@ -245,6 +251,8 @@ int main(int argc, char **argv)
 			if (argc <= 1)
 				usage();
 			batch_file = argv[1];
+		} else if (matches(opt, "-brief") == 0) {
+			++brief;
 		} else if (matches(opt, "-rcvbuf") == 0) {
 			unsigned int size;
 
@@ -269,13 +277,15 @@ int main(int argc, char **argv)
 		} else if (matches(opt, "-all") == 0) {
 			do_all = true;
 		} else {
-			fprintf(stderr, "Option \"%s\" is unknown, try \"ip -help\".\n", opt);
+			fprintf(stderr,
+				"Option \"%s\" is unknown, try \"ip -help\".\n",
+				opt);
 			exit(-1);
 		}
 		argc--;	argv++;
 	}
 
-	_SL_ = oneline ? "\\" : "\n" ;
+	_SL_ = oneline ? "\\" : "\n";
 
 	if (batch_file)
 		return batch(batch_file);
